C
C**************************
C**     LFN_SOFT_PROG    **
C**************************

C
CD-Routine: Monitor Integration Progress (Dummy) - LFN_SOFT_PROG
C This is a dummy routine which may be passed as the PROGRESS routine
C to the subroutine LFN_AUTO_SOFT, LFN_SOFT or LFN_SAINT. It is set up 
C with the required parameters and merely returns when called.
CD-end
CD-Fortran:
      SUBROUTINE LFN_SOFT_PROG (IPASS, NSPOT, ISPOT)
CD-end
      INCLUDE 'implicit_none.finc'
C
C Purpose: Log automatic soft limit determination errors
C
C Author:  John W. Campbell, November 1994
C
C Arguments:
C
      INTEGER IPASS
      INTEGER NSPOT
      INTEGER ISPOT
C
CD-Parameters:
C IPASS       i  (R)  Pass =0 box integration
C                          =1 get profiles
C                          =2 profile fitted integration
C NSPOT       i  (R)  No. of spots to be integrated
C ISPOT       i  (R)  Last spot integrated
CD-end
C
C====== Parameter statements
C 

C
C====== GLOBALS:
C

C
C====== FUNCTION TYPES:
C

C
C====== LOCALS:
C

C
C-------------------------------------------------------------------------------
C
      RETURN
      END
